add_ra_dec_from_object_name — MSUMastro toolbox 0.1 documentation

# add_ra_dec_from_object_name

`msumastro.header_processing.patchers.` `add_ra_dec_from_object_name`(directory=None, new_file_ext=None)

  Add RA/Dec to FITS file that has object name but no pointing.

  Parameters: | dir : str, optional Directory containing the files to be patched. Default is the current directory, `.` new_file_ext : str, optional Name added to the FITS files with updated header information. It is added to the base name of the input file, between the old file name and the .fit or .fits extension. Default is ‘new’.